==> digikam-3.0.0-rc.tar.bz2: digikam-3.0.0-rc/extra/kipi-plugins/removeredeyes/plugin/kipiplugin_removeredeyes.desktop.cmake <==
[Desktop Entry]
Name=Remove Red Eyes
Name[ast]=Desanicia los güeyos bermeyos
Name[bg]=Премахване на червени очи
Name[ca]=Eliminació d'ulls vermells
Name[ca@valencia]=Eliminació d'ulls vermells
Name[cs]=Odstranění červených očí
Name[da]=Fjern røde øjne
Name[de]=Rote Augen entfernen
Name[el]=Αφαίρεση κόκκινων ματιών
Name[en_GB]=Remove Red Eyes
Name[es]=Eliminar ojos rojos
Name[et]=Punasilmsuse eemaldamine
Name[eu]=Kendu begi gorriak
Name[fi]=Korjaa punasilmäisyysvirhe
Name[fr]=Suppression yeux rouges
Name[ga]=Ceartaigh Súile Dearga
Name[gl]=Eliminación de ollos vermellos
Name[hu]=Vörös szemek eltávolítása
Name[is]=RauðAugnaBani
Name[it]=Rimozione occhi rossi
Name[ja]=赤目修正
Name[km]=យក​ភ្នែក​ក្រហម​ចេញ
Name[lv]=Noņemt sarkanās acis
Name[nb]=Fjern røde øyne
Name[nds]=Rode Ogen richten
Name[nl]=Rode ogen verwijderen
Name[pa]=ਲਾਲ ਅੱਖ ਪਰਭਾਵ
Name[pl]=Usuń czerwone oczy
Name[pt]=Remoção de Olhos Vermelhos
Name[pt_BR]=Remover olhos vermelhos
Name[ro]=Înlătură ochii roșii
Name[ru]=Удаление эффекта «красных глаз»
Name[sk]=Odstránenie červených očí
Name[sl]=Odstrani rdeče oči
Name[sq]=Hiq Sytë e Kuq
Name[sv]=Ta bort röda ögon
Name[th]=ปรับแก้ตาแดง
Name[tr]=Kırmızı Gözleri Düzelt
Name[uk]=Вилучення «Червоних очей»
Name[x-test]=xxRemove Red Eyesxx
Name[zh_CN]=去除红眼
Name[zh_TW]=移除紅眼
Comment=A tool to remove red eyes automatically from images
Comment[ast]=Un ferramienta pa desaniciar los güeyos bermeyos automáticamente de les semeyes
Comment[bg]=Инструмент за автоматично премахване на червени очи от изображенията
Comment[ca]=Una eina per a eliminar automàticament els ulls vermells de les imatges
Comment[ca@valencia]=Una eina per a eliminar automàticament els ulls vermells de les imatges
Comment[cs]=Nástroj pro automatické odstranění červených očí
Comment[da]=Et værktøj til automatisk at fjerne røde øjne fra billeder
Comment[de]=Ein Werkzeug, um rote Augen automatisch von einem Bildern zu entfernen.
Comment[el]=Εργαλείο αυτόματης αφαίρεσης κόκκινων ματιών από εικόνες
Comment[en_GB]=A tool to remove red eyes automatically from images
Comment[es]=Una herramienta para eliminar automáticamente problemas de ojos rojos en las imágenes
Comment[et]=Tööriist punasilmsuse automaatseks eemaldamiseks pildilt
Comment[eu]=Begi gorriak irudietatik automatikoki kentzeko tresna
Comment[fr]=Outil de suppression automatique des yeux rouges à partir d'images
Comment[gl]=Unha ferramenta para eliminar automaticamente os ollos vermellos das imaxes
Comment[hu]=Egy eszköz a vörös szemek automatikus eltávolítására a képekből
Comment[is]=Verkfæri til að fjarlægja sjálfvirkt rauð augu úr myndum
Comment[it]=Uno strumento per rimuovere automaticamente gli occhi rossi nell'immagine
Comment[ja]=画像の赤目を自動的に修正するツール
Comment[km]=ឧបករណ៍​ត្រូវយក​ភ្នែក​ក្រហម​ចេញ​ដោយ​ស្វ័យ​ប្រវត្តិ​ពី​រូបភាព
Comment[lv]=Rīks automātiskai sarkano acu noņemšanai no attēliem
Comment[nb]=Et verktøy for å automatisk fjerne røde øyne fra bilder
Comment[nds]=En Warktüüch, dat automaatsch rode Ogen ut Biller wegmaakt
Comment[nl]=Een hulpmiddel voor het automatisch verwijderen van rode ogen in een afbeelding
Comment[pa]=ਚਿੱਤਰਾਂ ਤੋਂ ਲਾਲ ਅੱਖ (ਰੈੱਡ ਆਈ) ਨੂੰ ਆਟੋਮੈਟਿਕ ਹਟਾਉਣ ਵਾਲਾ ਟੂਲ
Comment[pl]=Narzędzie do automatycznego usuwania czerwonych oczu z obrazów
Comment[pt]=Uma ferramenta para remover automaticamente os olhos vermelhos das imagens
Comment[pt_BR]=Uma ferramenta para remover automaticamente os olhos vermelhos de imagens
Comment[ro]=O unealtă pentru înlăturarea automată a ochilor roșii din imagini
Comment[ru]=Инструмент для автоматического удаления эффекта «красных глаз» в изображениях
Comment[sk]=Nástroj na automatické odstránenie červených očí z obrázkov
Comment[sl]=Orodje, ki iz slik samodejno odstrani rdeče oči
Comment[sq]=Një mjet për të hequr sytë e kuq automatikisht nga imazhet
Comment[sv]=Ett verktyg för att automatiskt ta bort röda ögon från en bild
Comment[th]=เครื่องมือในการปรับแก้ตาแดงบนภาพโดยอัตโนมัติ
Comment[tr]=Resimdeki kırmızı gözleri otomatik olarak gidermek için bir araç
Comment[uk]=Інструмент для автоматичного вилучення наслідків ефекту «червоних очей» з зображень
Comment[x-test]=xxA tool to remove red eyes automatically from imagesxx
Comment[zh_CN]=一个自动从图像去除红眼的工具
Comment[zh_TW]=自動從影像移除紅眼的工具
ServiceTypes=KIPI/Plugin
Type=Service
Icon=draw-eraser
X-KDE-Library=kipiplugin_removeredeyes
X-KIPI-PluginCategories=Batch
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Andi Clemens, andi dot clemens at googlemail dot com

==> digikam_4.14.0.orig.tar.bz2: digikam-4.14.0/extra/kipi-plugins/removeredeyes/plugin/kipiplugin_removeredeyes.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Remove Red Eyes
Name=Remove Red Eyes
Name[ast]=Desanicia los güeyos bermeyos
Name[bg]=Премахване на червени очи
Name[bs]=Ukloni crvene oči
Name[ca]=Eliminació d'ulls vermells
Name[ca@valencia]=Eliminació d'ulls rojos
Name[cs]=Odstranění červených očí
Name[da]=Fjern røde øjne
Name[de]=Rote Augen entfernen
Name[el]=Αφαίρεση κόκκινων ματιών
Name[en_GB]=Remove Red Eyes
Name[es]=Eliminar ojos rojos
Name[et]=Punasilmsuse eemaldamine
Name[eu]=Kendu begi gorriak
Name[fi]=Punasilmäisyysvirheen korjaaminen
Name[fr]=Suppression de l'effet « Yeux rouges »
Name[ga]=Ceartaigh Súile Dearga
Name[gl]=Eliminación de ollos vermellos
Name[hu]=Vörös szemek eltávolítása
Name[is]=RauðAugnaBani
Name[it]=Rimozione occhi rossi
Name[ja]=赤目修正
Name[km]=យក​ភ្នែក​ក្រហម​ចេញ
Name[lv]=Noņemt sarkanās acis
Name[nb]=Fjern røde øyne
Name[nds]=Rode Ogen richten
Name[nl]=Rode ogen verwijderen
Name[pa]=ਲਾਲ ਅੱਖ ਪਰਭਾਵ
Name[pl]=Usuń czerwone oczy
Name[pt]=Remoção de Olhos Vermelhos
Name[pt_BR]=Remover olhos vermelhos
Name[ro]=Înlătură ochii roșii
Name[ru]=Удаление эффекта «красных глаз»
Name[sk]=Odstránenie červených očí
Name[sl]=Odstrani rdeče oči
Name[sq]=Hiq Sytë e Kuq
Name[sv]=Ta bort röda ögon
Name[th]=ปรับแก้ตาแดง
Name[tr]=Kırmızı Gözleri Düzelt
Name[uk]=Вилучення «Червоних очей»
Name[x-test]=xxRemove Red Eyesxx
Name[zh_CN]=去除红眼
Name[zh_TW]=移除紅眼
Comment=A tool to remove red eyes automatically from images
Comment[ast]=Un ferramienta pa desaniciar los güeyos bermeyos automáticamente de les semeyes
Comment[bg]=Инструмент за автоматично премахване на червени очи от изображенията
Comment[bs]=Alat za automatsko uklanjanje crvenih očiju sa slika
Comment[ca]=Una eina per a eliminar automàticament els ulls vermells de les imatges
Comment[ca@valencia]=Una eina per a eliminar automàticament els ulls rojos de les imatges
Comment[cs]=Nástroj pro automatické odstranění červených očí
Comment[da]=Et værktøj til automatisk at fjerne røde øjne fra billeder
Comment[de]=Ein Werkzeug, um rote Augen automatisch von einem Bildern zu entfernen.
Comment[el]=Εργαλείο αυτόματης αφαίρεσης κόκκινων ματιών από εικόνες
Comment[en_GB]=A tool to remove red eyes automatically from images
Comment[es]=Una herramienta para eliminar automáticamente problemas de ojos rojos en las imágenes
Comment[et]=Tööriist punasilmsuse automaatseks eemaldamiseks pildilt
Comment[eu]=Begi gorriak irudietatik automatikoki kentzeko tresna
Comment[fi]=Punasilmäisyysvirheen automaattinen korjaaminen kuvista
Comment[fr]=Outil de suppression automatique de l'effet « Yeux rouges » à partir d'images
Comment[gl]=Unha ferramenta para eliminar automaticamente os ollos vermellos das imaxes
Comment[hu]=Egy eszköz a vörös szemek automatikus eltávolítására a képekből
Comment[is]=Verkfæri til að fjarlægja sjálfvirkt rauð augu úr myndum
Comment[it]=Uno strumento per rimuovere automaticamente gli occhi rossi nell'immagine
Comment[ja]=画像の赤目を自動的に修正するツール
Comment[km]=ឧបករណ៍​ត្រូវយក​ភ្នែក​ក្រហម​ចេញ​ដោយ​ស្វ័យ​ប្រវត្តិ​ពី​រូបភាព
Comment[lv]=Rīks automātiskai sarkano acu noņemšanai no attēliem
Comment[nb]=Et verktøy for å automatisk fjerne røde øyne fra bilder
Comment[nds]=En Warktüüch, dat automaatsch rode Ogen ut Biller wegmaakt
Comment[nl]=Een hulpmiddel voor het automatisch verwijderen van rode ogen in een afbeelding
Comment[pa]=ਚਿੱਤਰਾਂ ਤੋਂ ਲਾਲ ਅੱਖ (ਰੈੱਡ ਆਈ) ਨੂੰ ਆਟੋਮੈਟਿਕ ਹਟਾਉਣ ਵਾਲਾ ਟੂਲ
Comment[pl]=Narzędzie do automatycznego usuwania czerwonych oczu z obrazów
Comment[pt]=Uma ferramenta para remover automaticamente os olhos vermelhos das imagens
Comment[pt_BR]=Ferramenta para remoção automática de olhos vermelhos em imagens
Comment[ro]=O unealtă pentru înlăturarea automată a ochilor roșii din imagini
Comment[ru]=Инструмент для автоматического удаления эффекта «красных глаз» в изображениях
Comment[sk]=Nástroj na automatické odstránenie červených očí z obrázkov
Comment[sl]=Orodje, ki iz slik samodejno odstrani rdeče oči
Comment[sq]=Një mjet për të hequr sytë e kuq automatikisht nga imazhet
Comment[sv]=Ett verktyg för att automatiskt ta bort röda ögon från en bild
Comment[th]=เครื่องมือในการปรับแก้ตาแดงบนภาพโดยอัตโนมัติ
Comment[tr]=Resimdeki kırmızı gözleri otomatik olarak gidermek için bir araç
Comment[uk]=Інструмент для автоматичного вилучення наслідків ефекту «червоних очей» з зображень
Comment[x-test]=xxA tool to remove red eyes automatically from imagesxx
Comment[zh_CN]=一个自动从图像去除红眼的工具
Comment[zh_TW]=自動從影像移除紅眼的工具
ServiceTypes=KIPI/Plugin
Type=Service
Icon=draw-eraser
X-KDE-Library=kipiplugin_removeredeyes
X-KIPI-PluginCategories=Batch
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Andi Clemens, andi dot clemens at googlemail dot com
